@@ -4,6 +4,9 @@ use Moose;
 
 use Geometry::Primitive::Rectangle;
 
+has 'height' => ( is => 'rw', isa => 'Num' );
+has 'width' => ( is => 'rw', isa => 'Num' );
+
 sub get_text_bounding_box {
     my ($self, $font, $text) = @_;
 
@@ -23,4 +26,6 @@ sub get_text_bounding_box {
     );
 }
 
+sub prepare {};
+
 1;
\ No newline at end of file
